function H = optkelley_diffhess(x, f, gc, heps)
// Compute a forward difference Hessian f''(x)
//
// Calling Sequence
//  H = optkelley_diffhess(x, f, gc, heps)
//
// Parameters
//  x: point
//  f: function. The calling sequence for the function is [func,grad]=f(x).
//  gc: current gradient, preevaluated
//  heps: difference increment, optional, default = 1.d-6
//  hess: hessian
//		
// Description
//   This function uses optkelley_dirdero to compute the columns, then symmetrize.
//
//   This code comes with no guarantee or warranty of any kind.
//
// Authors
// C. T. Kelley, March 17, 1998
// Yann Collette, Scilab port
// Michael Baudin, DIGITEO, 2010, Update to Scilab 5.2, formatted comments

//
//

[nargout, nargin] = argn();

if (nargin == 3) then
  heps = 1.d-6;
end

n=length(x);

for j=1:n
  zz    = zeros(n,1);
  zz(j) = 1;
  H(:,j)=optkelley_dirdero(x,zz,f,gc,heps);
end

//
// symmetrize
//

H = (H+H')*.5;
endfunction
