function z = optkelley_dirdero(x,w,f,gc,epsnew)
// Finite difference directional derivative for optimization - Approximate f''(x) w
// 
// Calling Sequence
//   z = optkelley_dirdero(x,w,f,gc,epsnew)
//
// Parameters
//           x: current point
//           w: direction
//           f: function, the calling sequence is [fun,grad]=f(x)
//           gc: current gradient, gc has usually been computed, before the call to optkelley_dirdero
//           epsnew: difference increment (optional), default = 1.d-6
//           z: directional derivative  
//
// Description
// This code comes with no guarantee or warranty of any kind.
//
// Authors
// C. T. Kelley, Dec 20, 1996
// Yann Collette, Scilab port
// Michael Baudin, DIGITEO, 2010, Update to Scilab 5.2, formatted comments
//
//
//
// 

[nargout, nargin] = argn();

if (nargin == 4) then
  epsnew = 1.d-6;
end

n = length(x);

//
// scale the step
//

if (norm(w) == 0) then
  z=zeros(n,1);
  return
end

epsnew = epsnew/norm(w);

//
// del and g1 could share the same space if storage
// is more important than clarity
//

del     = x+epsnew*w;
[f1,g1] = f(del);
z       = (g1 - gc)/epsnew;
endfunction
